import * as React from 'react'
import { View, ViewProperties } from 'react-native';

export interface AMapMarker {
    longitude: number;
    latitude: number;
    title: string;
    description?: string;
    params?: string;
}

export interface AMapCenterLocation {
    longitude: number;
    latitude: number;
}

export interface A2DMapViewProps extends ViewProperties {
    tracking: boolean;
    onLocationChanged?: (data:TrackingData) => void;
    onMarkClicked?: (params: AMapMarker) => void;
    onCenterChanged?: (center: AMapCenterLocation) => void;
}

export class AMapView extends React.Component<A2DMapViewProps> {
    constructor(props: A2DMapViewProps, context?: any);
    addMark(mark: AMapMarker): void;
    delMark(mark: AMapMarker): void;
}


export interface TrackingData {
    latitude: number;
    longitude: number;
    city: string;
    address: string;
    province: string;
}

export interface AbstractAMapLocation {
    new () : AbstractAMapLocation;
    instance() : PromiseLike<string>;
    start() : void;
    stop() : void;
    addTracker(tracker: (data: TrackingData)=>void) : void;
    delTracker(tracker: (data: TrackingData)=>void) : void;
}

export const AMapLocation : AbstractAMapLocation;
export type AMapLocation = AbstractAMapLocation


