import React, { Component } from 'react';
import { PropTypes } from 'prop-types';
import ReactNative, { ViewPropTypes, Text, requireNativeComponent, View, DeviceEventEmitter } from 'react-native';
import { NativeModules, UIManager } from 'react-native';

export class AMapLocation {
  
  constructor() {
    this.mOnChangedListeners = [];
    this.mNative = NativeModules.AMapLocation;
    if (typeof this.mNative === 'undefined' || this.mNative === null) {
      console.log("failed to get AMapLocation from native package!");
      return;
    }
    DeviceEventEmitter.addListener('locationchanged', (data) => {
      for(var i = 0; i < this.mOnChangedListeners.length; i++) {
        var handler = this.mOnChangedListeners[i];
        handler(data); 
      }
    });
    this.mNative.setTracking(true);
  }

  addTracker(tracker) {
    for(var i = 0; i < this.mOnChangedListeners.length; i++) {
      if (this.mOnChangedListeners[i] === tracker) return;
    }
    this.mOnChangedListeners.push(tracker);
    this.mNative.setTrackingEventEnabled(true);
    
  }

  delTracker(tracker) {
    for(var i = 0; i < this.mOnChangedListeners.length; i++) {
      if (this.mOnChangedListeners[i] === tracker) {
        this.mOnChangedListeners.splice(i, 1);
      }
    }
    if (this.mOnChangedListeners.length === 0) {
    	this.mNative.setTrackingEventEnabled(false);
    }
  }

  async instance() {
    return (this.mNative !== null) ? (await this.mNative.getInstance()) : "";
  }

}

export class AMapView extends Component {

	static propTypes = {
	    ...ViewPropTypes,
	    tracking: PropTypes.bool,
	    onLocationChanged: PropTypes.func,
	    onMarkClicked: PropTypes.func,
	    onCenterChanged: PropTypes.func,
	}
 
	constructor(props, context) {
		super(props, context); 
		this.state = { 
			tracking: (typeof this.props.tracking === 'undefined') ? true : this.props.tracking
		};
		this._OnLocationChanged = this._OnLocationChanged.bind(this);
		this._OnMarkClicked = this._OnMarkClicked.bind(this);
		this._OnCameraCenterChanged = this._OnCameraCenterChanged.bind(this);
	}

	_OnLocationChanged(event) {
		if (typeof this.props.onLocationChanged === 'function') {
			this.props.onLocationChanged(event.nativeEvent);
		}
	}

	_OnMarkClicked(event) {
		if (typeof this.props.onMarkClicked === 'function') {
			this.props.onMarkClicked(event.nativeEvent);
		}
	}

	_OnCameraCenterChanged(event) {
		if (typeof this.props.onCenterChanged === 'function') {
			this.props.onCenterChanged(event.nativeEvent);
		}
	}

	addMark(mark) {
		if (this.mNative != null) {
			UIManager.dispatchViewManagerCommand(ReactNative.findNodeHandle(this.mNative), UIManager.A2DMapView.Commands.CmdKeyAddMapMark, [mark]);
		}
	}

	render() {
		return (
			<A2DMapView style={{flex: 1, backgroundColor: 'red'}}
			 ref={(native)=>{this.mNative = native;}} 
			 tracking={this.state.tracking} 
			 onMarkClicked={this._OnMarkClicked} 
			 onLocationChanged={this._OnLocationChanged}
			 onCameraCenterChanged={this._OnCameraCenterChanged}
			 /> 
		);
	} 
}

var A2DMapView = requireNativeComponent('A2DMapView', AMapView);

  
